import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LogsIndexConfig extends cdktf.TerraformMetaArguments {
    /**
    * The number of log events you can send in this index per day before you are rate-limited.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#daily_limit LogsIndex#daily_limit}
    */
    readonly dailyLimit?: number;
    /**
    * If true, sets the daily_limit value to null and the index is not limited on a daily basis (any specified daily_limit value in the request is ignored). If false or omitted, the index's current daily_limit is maintained.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#disable_daily_limit LogsIndex#disable_daily_limit}
    */
    readonly disableDailyLimit?: boolean | cdktf.IResolvable;
    /**
    * The name of the index.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#name LogsIndex#name}
    */
    readonly name: string;
    /**
    * The number of days before logs are deleted from this index.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#retention_days LogsIndex#retention_days}
    */
    readonly retentionDays?: number;
    /**
    * exclusion_filter block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#exclusion_filter LogsIndex#exclusion_filter}
    */
    readonly exclusionFilter?: LogsIndexExclusionFilter[] | cdktf.IResolvable;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#filter LogsIndex#filter}
    */
    readonly filter: LogsIndexFilter;
}
export interface LogsIndexExclusionFilterFilter {
    /**
    * Only logs matching the filter criteria and the query of the parent index will be considered for this exclusion filter.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#query LogsIndex#query}
    */
    readonly query?: string;
    /**
    * The fraction of logs excluded by the exclusion filter, when active.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#sample_rate LogsIndex#sample_rate}
    */
    readonly sampleRate?: number;
}
export declare function logsIndexExclusionFilterFilterToTerraform(struct?: LogsIndexExclusionFilterFilter | cdktf.IResolvable): any;
export interface LogsIndexExclusionFilter {
    /**
    * A boolean stating if the exclusion is active or not.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#is_enabled LogsIndex#is_enabled}
    */
    readonly isEnabled?: boolean | cdktf.IResolvable;
    /**
    * The name of the exclusion filter.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#name LogsIndex#name}
    */
    readonly name?: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#filter LogsIndex#filter}
    */
    readonly filter?: LogsIndexExclusionFilterFilter[] | cdktf.IResolvable;
}
export declare function logsIndexExclusionFilterToTerraform(struct?: LogsIndexExclusionFilter | cdktf.IResolvable): any;
export interface LogsIndexFilter {
    /**
    * Logs filter criteria. Only logs matching this filter criteria are considered for this index.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index#query LogsIndex#query}
    */
    readonly query: string;
}
export declare function logsIndexFilterToTerraform(struct?: LogsIndexFilterOutputReference | LogsIndexFilter): any;
export declare class LogsIndexFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): LogsIndexFilter | undefined;
    set internalValue(value: LogsIndexFilter | undefined);
    private _query?;
    get query(): string;
    set query(value: string);
    get queryInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/datadog/r/logs_index datadog_logs_index}
*/
export declare class LogsIndex extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_logs_index";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/logs_index datadog_logs_index} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LogsIndexConfig
    */
    constructor(scope: Construct, id: string, config: LogsIndexConfig);
    private _dailyLimit?;
    get dailyLimit(): number;
    set dailyLimit(value: number);
    resetDailyLimit(): void;
    get dailyLimitInput(): number | undefined;
    private _disableDailyLimit?;
    get disableDailyLimit(): boolean | cdktf.IResolvable;
    set disableDailyLimit(value: boolean | cdktf.IResolvable);
    resetDisableDailyLimit(): void;
    get disableDailyLimitInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _retentionDays?;
    get retentionDays(): number;
    set retentionDays(value: number);
    resetRetentionDays(): void;
    get retentionDaysInput(): number | undefined;
    private _exclusionFilter?;
    get exclusionFilter(): LogsIndexExclusionFilter[] | cdktf.IResolvable;
    set exclusionFilter(value: LogsIndexExclusionFilter[] | cdktf.IResolvable);
    resetExclusionFilter(): void;
    get exclusionFilterInput(): cdktf.IResolvable | LogsIndexExclusionFilter[] | undefined;
    private _filter;
    get filter(): LogsIndexFilterOutputReference;
    putFilter(value: LogsIndexFilter): void;
    get filterInput(): LogsIndexFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
