import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MonitorConfig extends cdktf.TerraformMetaArguments {
    /**
    * A boolean indicating whether or not to include a list of log values which triggered the alert. This is only used by log monitors. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#enable_logs_sample Monitor#enable_logs_sample}
    */
    readonly enableLogsSample?: boolean | cdktf.IResolvable;
    /**
    * A message to include with a re-notification. Supports the `@username` notification allowed elsewhere.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#escalation_message Monitor#escalation_message}
    */
    readonly escalationMessage?: string;
    /**
    * (Only applies to metric alert) Time (in seconds) to delay evaluation, as a non-negative integer.
  
  For example, if the value is set to `300` (5min), the `timeframe` is set to `last_5m` and the time is 7:00, the monitor will evaluate data from 6:50 to 6:55. This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor will always have data during evaluation.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#evaluation_delay Monitor#evaluation_delay}
    */
    readonly evaluationDelay?: number;
    /**
    * A boolean indicating whether this monitor can be deleted even if it’s referenced by other resources (e.g. SLO, composite monitor).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#force_delete Monitor#force_delete}
    */
    readonly forceDelete?: boolean | cdktf.IResolvable;
    /**
    * Whether or not to trigger one alert if any source breaches a threshold. This is only used by log monitors. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#groupby_simple_monitor Monitor#groupby_simple_monitor}
    */
    readonly groupbySimpleMonitor?: boolean | cdktf.IResolvable;
    /**
    * A boolean indicating whether notifications from this monitor automatically insert its triggering tags into the title. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#include_tags Monitor#include_tags}
    */
    readonly includeTags?: boolean | cdktf.IResolvable;
    /**
    * A boolean indicating whether changes to this monitor should be restricted to the creator or admins. Defaults to `false`. **Deprecated.** Use `restricted_roles`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#locked Monitor#locked}
    */
    readonly locked?: boolean | cdktf.IResolvable;
    /**
    * A message to include with notifications for this monitor.
  
  Email notifications can be sent to specific users by using the same `@username` notation as events.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#message Monitor#message}
    */
    readonly message: string;
    /**
    * Name of Datadog monitor.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#name Monitor#name}
    */
    readonly name: string;
    /**
    * The time (in seconds) to skip evaluations for new groups.
  
  `new_group_delay` overrides `new_host_delay` if it is set to a nonzero value.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#new_group_delay Monitor#new_group_delay}
    */
    readonly newGroupDelay?: number;
    /**
    * **Deprecated**. See `new_group_delay`. Time (in seconds) to allow a host to boot and applications to fully start before starting the evaluation of monitor results. Should be a non-negative integer. This value is ignored for simple monitors and monitors not grouped by host. Defaults to `300`. The only case when this should be used is to override the default and set `new_host_delay` to zero for monitors grouped by host. **Deprecated.** Use `new_group_delay` except when setting `new_host_delay` to zero.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#new_host_delay Monitor#new_host_delay}
    */
    readonly newHostDelay?: number;
    /**
    * The number of minutes before a monitor will notify when data stops reporting. Provider defaults to 10 minutes.
  
  We recommend at least 2x the monitor timeframe for metric alerts or 2 minutes for service checks.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#no_data_timeframe Monitor#no_data_timeframe}
    */
    readonly noDataTimeframe?: number;
    /**
    * A boolean indicating whether tagged users will be notified on changes to this monitor. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#notify_audit Monitor#notify_audit}
    */
    readonly notifyAudit?: boolean | cdktf.IResolvable;
    /**
    * A boolean indicating whether this monitor will notify when data stops reporting. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#notify_no_data Monitor#notify_no_data}
    */
    readonly notifyNoData?: boolean | cdktf.IResolvable;
    /**
    * Integer from 1 (high) to 5 (low) indicating alert severity.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#priority Monitor#priority}
    */
    readonly priority?: number;
    /**
    * The monitor query to notify on. Note this is not the same query you see in the UI and the syntax is different depending on the monitor type, please see the [API Reference](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor) for details. `terraform plan` will validate query contents unless `validate` is set to `false`.
  
  **Note:** APM latency data is now available as Distribution Metrics. Existing monitors have been migrated automatically but all terraformed monitors can still use the existing metrics. We strongly recommend updating monitor definitions to query the new metrics. To learn more, or to see examples of how to update your terraform definitions to utilize the new distribution metrics, see the [detailed doc](https://docs.datadoghq.com/tracing/guide/ddsketch_trace_metrics/).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#query Monitor#query}
    */
    readonly query: string;
    /**
    * The number of minutes after the last notification before a monitor will re-notify on the current status. It will only re-notify if it's not resolved.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#renotify_interval Monitor#renotify_interval}
    */
    readonly renotifyInterval?: number;
    /**
    * The number of re-notification messages that should be sent on the current status.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#renotify_occurrences Monitor#renotify_occurrences}
    */
    readonly renotifyOccurrences?: number;
    /**
    * The types of statuses for which re-notification messages should be sent. Valid values are `alert`, `warn`, `no data`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#renotify_statuses Monitor#renotify_statuses}
    */
    readonly renotifyStatuses?: string[];
    /**
    * A boolean indicating whether this monitor needs a full window of data before it's evaluated.
  
  We highly recommend you set this to `false` for sparse metrics, otherwise some evaluations will be skipped. Default: `true` for `on average`, `at all times` and `in total` aggregation. `false` otherwise.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#require_full_window Monitor#require_full_window}
    */
    readonly requireFullWindow?: boolean | cdktf.IResolvable;
    /**
    * A list of unique role identifiers to define which roles are allowed to edit the monitor. Editing a monitor includes any updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. Roles unique identifiers can be pulled from the [Roles API](https://docs.datadoghq.com/api/latest/roles/#list-roles) in the `data.id` field.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#restricted_roles Monitor#restricted_roles}
    */
    readonly restrictedRoles?: string[];
    /**
    * A list of tags to associate with your monitor. This can help you categorize and filter monitors in the manage monitors page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#tags Monitor#tags}
    */
    readonly tags?: string[];
    /**
    * The number of hours of the monitor not reporting data before it will automatically resolve from a triggered state.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#timeout_h Monitor#timeout_h}
    */
    readonly timeoutH?: number;
    /**
    * The type of the monitor. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API [documentation page](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor). Note: The monitor type cannot be changed after a monitor is created. Valid values are `composite`, `event alert`, `log alert`, `metric alert`, `process alert`, `query alert`, `rum alert`, `service check`, `synthetics alert`, `trace-analytics alert`, `slo alert`, `event-v2 alert`, `audit alert`, `ci-pipelines alert`, `error-tracking alert`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#type Monitor#type}
    */
    readonly type: string;
    /**
    * If set to `false`, skip the validation call done during plan.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#validate Monitor#validate}
    */
    readonly validate?: boolean | cdktf.IResolvable;
    /**
    * monitor_threshold_windows block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#monitor_threshold_windows Monitor#monitor_threshold_windows}
    */
    readonly monitorThresholdWindows?: MonitorMonitorThresholdWindows;
    /**
    * monitor_thresholds block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#monitor_thresholds Monitor#monitor_thresholds}
    */
    readonly monitorThresholds?: MonitorMonitorThresholds;
}
export interface MonitorMonitorThresholdWindows {
    /**
    * Describes how long an anomalous metric must be normal before the alert recovers.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#recovery_window Monitor#recovery_window}
    */
    readonly recoveryWindow?: string;
    /**
    * Describes how long a metric must be anomalous before an alert triggers.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#trigger_window Monitor#trigger_window}
    */
    readonly triggerWindow?: string;
}
export declare function monitorMonitorThresholdWindowsToTerraform(struct?: MonitorMonitorThresholdWindowsOutputReference | MonitorMonitorThresholdWindows): any;
export declare class MonitorMonitorThresholdWindowsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MonitorMonitorThresholdWindows | undefined;
    set internalValue(value: MonitorMonitorThresholdWindows | undefined);
    private _recoveryWindow?;
    get recoveryWindow(): string;
    set recoveryWindow(value: string);
    resetRecoveryWindow(): void;
    get recoveryWindowInput(): string | undefined;
    private _triggerWindow?;
    get triggerWindow(): string;
    set triggerWindow(value: string);
    resetTriggerWindow(): void;
    get triggerWindowInput(): string | undefined;
}
export interface MonitorMonitorThresholds {
    /**
    * The monitor `CRITICAL` threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#critical Monitor#critical}
    */
    readonly critical?: string;
    /**
    * The monitor `CRITICAL` recovery threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#critical_recovery Monitor#critical_recovery}
    */
    readonly criticalRecovery?: string;
    /**
    * The monitor `OK` threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#ok Monitor#ok}
    */
    readonly ok?: string;
    /**
    * The monitor `UNKNOWN` threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#unknown Monitor#unknown}
    */
    readonly unknown?: string;
    /**
    * The monitor `WARNING` threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#warning Monitor#warning}
    */
    readonly warning?: string;
    /**
    * The monitor `WARNING` recovery threshold. Must be a number.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor#warning_recovery Monitor#warning_recovery}
    */
    readonly warningRecovery?: string;
}
export declare function monitorMonitorThresholdsToTerraform(struct?: MonitorMonitorThresholdsOutputReference | MonitorMonitorThresholds): any;
export declare class MonitorMonitorThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MonitorMonitorThresholds | undefined;
    set internalValue(value: MonitorMonitorThresholds | undefined);
    private _critical?;
    get critical(): string;
    set critical(value: string);
    resetCritical(): void;
    get criticalInput(): string | undefined;
    private _criticalRecovery?;
    get criticalRecovery(): string;
    set criticalRecovery(value: string);
    resetCriticalRecovery(): void;
    get criticalRecoveryInput(): string | undefined;
    private _ok?;
    get ok(): string;
    set ok(value: string);
    resetOk(): void;
    get okInput(): string | undefined;
    private _unknown?;
    get unknown(): string;
    set unknown(value: string);
    resetUnknown(): void;
    get unknownInput(): string | undefined;
    private _warning?;
    get warning(): string;
    set warning(value: string);
    resetWarning(): void;
    get warningInput(): string | undefined;
    private _warningRecovery?;
    get warningRecovery(): string;
    set warningRecovery(value: string);
    resetWarningRecovery(): void;
    get warningRecoveryInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/datadog/r/monitor datadog_monitor}
*/
export declare class Monitor extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_monitor";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/monitor datadog_monitor} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MonitorConfig
    */
    constructor(scope: Construct, id: string, config: MonitorConfig);
    private _enableLogsSample?;
    get enableLogsSample(): boolean | cdktf.IResolvable;
    set enableLogsSample(value: boolean | cdktf.IResolvable);
    resetEnableLogsSample(): void;
    get enableLogsSampleInput(): boolean | cdktf.IResolvable | undefined;
    private _escalationMessage?;
    get escalationMessage(): string;
    set escalationMessage(value: string);
    resetEscalationMessage(): void;
    get escalationMessageInput(): string | undefined;
    private _evaluationDelay?;
    get evaluationDelay(): number;
    set evaluationDelay(value: number);
    resetEvaluationDelay(): void;
    get evaluationDelayInput(): number | undefined;
    private _forceDelete?;
    get forceDelete(): boolean | cdktf.IResolvable;
    set forceDelete(value: boolean | cdktf.IResolvable);
    resetForceDelete(): void;
    get forceDeleteInput(): boolean | cdktf.IResolvable | undefined;
    private _groupbySimpleMonitor?;
    get groupbySimpleMonitor(): boolean | cdktf.IResolvable;
    set groupbySimpleMonitor(value: boolean | cdktf.IResolvable);
    resetGroupbySimpleMonitor(): void;
    get groupbySimpleMonitorInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _includeTags?;
    get includeTags(): boolean | cdktf.IResolvable;
    set includeTags(value: boolean | cdktf.IResolvable);
    resetIncludeTags(): void;
    get includeTagsInput(): boolean | cdktf.IResolvable | undefined;
    private _locked?;
    get locked(): boolean | cdktf.IResolvable;
    set locked(value: boolean | cdktf.IResolvable);
    resetLocked(): void;
    get lockedInput(): boolean | cdktf.IResolvable | undefined;
    private _message?;
    get message(): string;
    set message(value: string);
    get messageInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _newGroupDelay?;
    get newGroupDelay(): number;
    set newGroupDelay(value: number);
    resetNewGroupDelay(): void;
    get newGroupDelayInput(): number | undefined;
    private _newHostDelay?;
    get newHostDelay(): number;
    set newHostDelay(value: number);
    resetNewHostDelay(): void;
    get newHostDelayInput(): number | undefined;
    private _noDataTimeframe?;
    get noDataTimeframe(): number;
    set noDataTimeframe(value: number);
    resetNoDataTimeframe(): void;
    get noDataTimeframeInput(): number | undefined;
    private _notifyAudit?;
    get notifyAudit(): boolean | cdktf.IResolvable;
    set notifyAudit(value: boolean | cdktf.IResolvable);
    resetNotifyAudit(): void;
    get notifyAuditInput(): boolean | cdktf.IResolvable | undefined;
    private _notifyNoData?;
    get notifyNoData(): boolean | cdktf.IResolvable;
    set notifyNoData(value: boolean | cdktf.IResolvable);
    resetNotifyNoData(): void;
    get notifyNoDataInput(): boolean | cdktf.IResolvable | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    resetPriority(): void;
    get priorityInput(): number | undefined;
    private _query?;
    get query(): string;
    set query(value: string);
    get queryInput(): string | undefined;
    private _renotifyInterval?;
    get renotifyInterval(): number;
    set renotifyInterval(value: number);
    resetRenotifyInterval(): void;
    get renotifyIntervalInput(): number | undefined;
    private _renotifyOccurrences?;
    get renotifyOccurrences(): number;
    set renotifyOccurrences(value: number);
    resetRenotifyOccurrences(): void;
    get renotifyOccurrencesInput(): number | undefined;
    private _renotifyStatuses?;
    get renotifyStatuses(): string[];
    set renotifyStatuses(value: string[]);
    resetRenotifyStatuses(): void;
    get renotifyStatusesInput(): string[] | undefined;
    private _requireFullWindow?;
    get requireFullWindow(): boolean | cdktf.IResolvable;
    set requireFullWindow(value: boolean | cdktf.IResolvable);
    resetRequireFullWindow(): void;
    get requireFullWindowInput(): boolean | cdktf.IResolvable | undefined;
    private _restrictedRoles?;
    get restrictedRoles(): string[];
    set restrictedRoles(value: string[]);
    resetRestrictedRoles(): void;
    get restrictedRolesInput(): string[] | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _timeoutH?;
    get timeoutH(): number;
    set timeoutH(value: number);
    resetTimeoutH(): void;
    get timeoutHInput(): number | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _validate?;
    get validate(): boolean | cdktf.IResolvable;
    set validate(value: boolean | cdktf.IResolvable);
    resetValidate(): void;
    get validateInput(): boolean | cdktf.IResolvable | undefined;
    private _monitorThresholdWindows;
    get monitorThresholdWindows(): MonitorMonitorThresholdWindowsOutputReference;
    putMonitorThresholdWindows(value: MonitorMonitorThresholdWindows): void;
    resetMonitorThresholdWindows(): void;
    get monitorThresholdWindowsInput(): MonitorMonitorThresholdWindows | undefined;
    private _monitorThresholds;
    get monitorThresholds(): MonitorMonitorThresholdsOutputReference;
    putMonitorThresholds(value: MonitorMonitorThresholds): void;
    resetMonitorThresholds(): void;
    get monitorThresholdsInput(): MonitorMonitorThresholds | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
