import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SecurityMonitoringRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether the rule is enabled.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#enabled SecurityMonitoringRule#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Whether the notifications include the triggering group-by values in their title.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#has_extended_title SecurityMonitoringRule#has_extended_title}
    */
    readonly hasExtendedTitle?: boolean | cdktf.IResolvable;
    /**
    * Message for generated signals.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#message SecurityMonitoringRule#message}
    */
    readonly message: string;
    /**
    * The name of the rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#name SecurityMonitoringRule#name}
    */
    readonly name: string;
    /**
    * Tags for generated signals.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#tags SecurityMonitoringRule#tags}
    */
    readonly tags?: string[];
    /**
    * The rule type. Valid values are `log_detection`, `infrastructure_configuration`, `workload_security`, `cloud_configuration`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#type SecurityMonitoringRule#type}
    */
    readonly type?: string;
    /**
    * case block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#case SecurityMonitoringRule#case}
    */
    readonly case: SecurityMonitoringRuleCase[] | cdktf.IResolvable;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#filter SecurityMonitoringRule#filter}
    */
    readonly filter?: SecurityMonitoringRuleFilter[] | cdktf.IResolvable;
    /**
    * options block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#options SecurityMonitoringRule#options}
    */
    readonly options?: SecurityMonitoringRuleOptions;
    /**
    * query block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#query SecurityMonitoringRule#query}
    */
    readonly query: SecurityMonitoringRuleQuery[] | cdktf.IResolvable;
}
export interface SecurityMonitoringRuleCase {
    /**
    * A rule case contains logical operations (`>`,`>=`, `&&`, `||`) to determine if a signal should be generated based on the event counts in the previously defined queries.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#condition SecurityMonitoringRule#condition}
    */
    readonly condition?: string;
    /**
    * Name of the case.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#name SecurityMonitoringRule#name}
    */
    readonly name?: string;
    /**
    * Notification targets for each rule case.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#notifications SecurityMonitoringRule#notifications}
    */
    readonly notifications?: string[];
    /**
    * Severity of the Security Signal. Valid values are `info`, `low`, `medium`, `high`, `critical`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#status SecurityMonitoringRule#status}
    */
    readonly status: string;
}
export declare function securityMonitoringRuleCaseToTerraform(struct?: SecurityMonitoringRuleCase | cdktf.IResolvable): any;
export interface SecurityMonitoringRuleFilter {
    /**
    * The type of filtering action. Valid values are `require`, `suppress`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#action SecurityMonitoringRule#action}
    */
    readonly action: string;
    /**
    * Query for selecting logs to apply the filtering action.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#query SecurityMonitoringRule#query}
    */
    readonly query: string;
}
export declare function securityMonitoringRuleFilterToTerraform(struct?: SecurityMonitoringRuleFilter | cdktf.IResolvable): any;
export interface SecurityMonitoringRuleOptionsImpossibleTravelOptions {
    /**
    * If true, signals are suppressed for the first 24 hours. In that time, Datadog learns the user's regular access locations. This can be helpful to reduce noise and infer VPN usage or credentialed API access.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#baseline_user_locations SecurityMonitoringRule#baseline_user_locations}
    */
    readonly baselineUserLocations?: boolean | cdktf.IResolvable;
}
export declare function securityMonitoringRuleOptionsImpossibleTravelOptionsToTerraform(struct?: SecurityMonitoringRuleOptionsImpossibleTravelOptionsOutputReference | SecurityMonitoringRuleOptionsImpossibleTravelOptions): any;
export declare class SecurityMonitoringRuleOptionsImpossibleTravelOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SecurityMonitoringRuleOptionsImpossibleTravelOptions | undefined;
    set internalValue(value: SecurityMonitoringRuleOptionsImpossibleTravelOptions | undefined);
    private _baselineUserLocations?;
    get baselineUserLocations(): boolean | cdktf.IResolvable;
    set baselineUserLocations(value: boolean | cdktf.IResolvable);
    resetBaselineUserLocations(): void;
    get baselineUserLocationsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface SecurityMonitoringRuleOptionsNewValueOptions {
    /**
    * The duration in days after which a learned value is forgotten. Valid values are `1`, `2`, `7`, `14`, `21`, `28`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#forget_after SecurityMonitoringRule#forget_after}
    */
    readonly forgetAfter: number;
    /**
    * The duration in days during which values are learned, and after which signals will be generated for values that weren't learned. If set to 0, a signal will be generated for all new values after the first value is learned. Valid values are `0`, `1`, `7`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#learning_duration SecurityMonitoringRule#learning_duration}
    */
    readonly learningDuration: number;
}
export declare function securityMonitoringRuleOptionsNewValueOptionsToTerraform(struct?: SecurityMonitoringRuleOptionsNewValueOptionsOutputReference | SecurityMonitoringRuleOptionsNewValueOptions): any;
export declare class SecurityMonitoringRuleOptionsNewValueOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SecurityMonitoringRuleOptionsNewValueOptions | undefined;
    set internalValue(value: SecurityMonitoringRuleOptionsNewValueOptions | undefined);
    private _forgetAfter?;
    get forgetAfter(): number;
    set forgetAfter(value: number);
    get forgetAfterInput(): number | undefined;
    private _learningDuration?;
    get learningDuration(): number;
    set learningDuration(value: number);
    get learningDurationInput(): number | undefined;
}
export interface SecurityMonitoringRuleOptions {
    /**
    * The detection method. Valid values are `threshold`, `new_value`, `anomaly_detection`, `impossible_travel`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#detection_method SecurityMonitoringRule#detection_method}
    */
    readonly detectionMethod?: string;
    /**
    * A time window is specified to match when at least one of the cases matches true. This is a sliding window and evaluates in real time. Valid values are `0`, `60`, `300`, `600`, `900`, `1800`, `3600`, `7200`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#evaluation_window SecurityMonitoringRule#evaluation_window}
    */
    readonly evaluationWindow?: number;
    /**
    * Once a signal is generated, the signal will remain “open” if a case is matched at least once within this keep alive window. Valid values are `0`, `60`, `300`, `600`, `900`, `1800`, `3600`, `7200`, `10800`, `21600`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#keep_alive SecurityMonitoringRule#keep_alive}
    */
    readonly keepAlive: number;
    /**
    * A signal will “close” regardless of the query being matched once the time exceeds the maximum duration. This time is calculated from the first seen timestamp. Valid values are `0`, `60`, `300`, `600`, `900`, `1800`, `3600`, `7200`, `10800`, `21600`, `43200`, `86400`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#max_signal_duration SecurityMonitoringRule#max_signal_duration}
    */
    readonly maxSignalDuration: number;
    /**
    * impossible_travel_options block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#impossible_travel_options SecurityMonitoringRule#impossible_travel_options}
    */
    readonly impossibleTravelOptions?: SecurityMonitoringRuleOptionsImpossibleTravelOptions;
    /**
    * new_value_options block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#new_value_options SecurityMonitoringRule#new_value_options}
    */
    readonly newValueOptions?: SecurityMonitoringRuleOptionsNewValueOptions;
}
export declare function securityMonitoringRuleOptionsToTerraform(struct?: SecurityMonitoringRuleOptionsOutputReference | SecurityMonitoringRuleOptions): any;
export declare class SecurityMonitoringRuleOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SecurityMonitoringRuleOptions | undefined;
    set internalValue(value: SecurityMonitoringRuleOptions | undefined);
    private _detectionMethod?;
    get detectionMethod(): string;
    set detectionMethod(value: string);
    resetDetectionMethod(): void;
    get detectionMethodInput(): string | undefined;
    private _evaluationWindow?;
    get evaluationWindow(): number;
    set evaluationWindow(value: number);
    resetEvaluationWindow(): void;
    get evaluationWindowInput(): number | undefined;
    private _keepAlive?;
    get keepAlive(): number;
    set keepAlive(value: number);
    get keepAliveInput(): number | undefined;
    private _maxSignalDuration?;
    get maxSignalDuration(): number;
    set maxSignalDuration(value: number);
    get maxSignalDurationInput(): number | undefined;
    private _impossibleTravelOptions;
    get impossibleTravelOptions(): SecurityMonitoringRuleOptionsImpossibleTravelOptionsOutputReference;
    putImpossibleTravelOptions(value: SecurityMonitoringRuleOptionsImpossibleTravelOptions): void;
    resetImpossibleTravelOptions(): void;
    get impossibleTravelOptionsInput(): SecurityMonitoringRuleOptionsImpossibleTravelOptions | undefined;
    private _newValueOptions;
    get newValueOptions(): SecurityMonitoringRuleOptionsNewValueOptionsOutputReference;
    putNewValueOptions(value: SecurityMonitoringRuleOptionsNewValueOptions): void;
    resetNewValueOptions(): void;
    get newValueOptionsInput(): SecurityMonitoringRuleOptionsNewValueOptions | undefined;
}
export interface SecurityMonitoringRuleQueryAgentRule {
    /**
    * **Deprecated**. It won't be applied anymore.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#agent_rule_id SecurityMonitoringRule#agent_rule_id}
    */
    readonly agentRuleId: string;
    /**
    * **Deprecated**. It won't be applied anymore.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#expression SecurityMonitoringRule#expression}
    */
    readonly expression: string;
}
export declare function securityMonitoringRuleQueryAgentRuleToTerraform(struct?: SecurityMonitoringRuleQueryAgentRule | cdktf.IResolvable): any;
export interface SecurityMonitoringRuleQuery {
    /**
    * The aggregation type. Valid values are `count`, `cardinality`, `sum`, `max`, `new_value`, `geo_data`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#aggregation SecurityMonitoringRule#aggregation}
    */
    readonly aggregation?: string;
    /**
    * Field for which the cardinality is measured. Sent as an array.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#distinct_fields SecurityMonitoringRule#distinct_fields}
    */
    readonly distinctFields?: string[];
    /**
    * Fields to group by.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#group_by_fields SecurityMonitoringRule#group_by_fields}
    */
    readonly groupByFields?: string[];
    /**
    * The target field to aggregate over when using the sum or max aggregations.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#metric SecurityMonitoringRule#metric}
    */
    readonly metric?: string;
    /**
    * Name of the query.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#name SecurityMonitoringRule#name}
    */
    readonly name?: string;
    /**
    * Query to run on logs.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#query SecurityMonitoringRule#query}
    */
    readonly query: string;
    /**
    * agent_rule block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule#agent_rule SecurityMonitoringRule#agent_rule}
    */
    readonly agentRule?: SecurityMonitoringRuleQueryAgentRule[] | cdktf.IResolvable;
}
export declare function securityMonitoringRuleQueryToTerraform(struct?: SecurityMonitoringRuleQuery | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule datadog_security_monitoring_rule}
*/
export declare class SecurityMonitoringRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_security_monitoring_rule";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/security_monitoring_rule datadog_security_monitoring_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SecurityMonitoringRuleConfig
    */
    constructor(scope: Construct, id: string, config: SecurityMonitoringRuleConfig);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _hasExtendedTitle?;
    get hasExtendedTitle(): boolean | cdktf.IResolvable;
    set hasExtendedTitle(value: boolean | cdktf.IResolvable);
    resetHasExtendedTitle(): void;
    get hasExtendedTitleInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _message?;
    get message(): string;
    set message(value: string);
    get messageInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _case?;
    get case(): SecurityMonitoringRuleCase[] | cdktf.IResolvable;
    set case(value: SecurityMonitoringRuleCase[] | cdktf.IResolvable);
    get caseInput(): cdktf.IResolvable | SecurityMonitoringRuleCase[] | undefined;
    private _filter?;
    get filter(): SecurityMonitoringRuleFilter[] | cdktf.IResolvable;
    set filter(value: SecurityMonitoringRuleFilter[] | cdktf.IResolvable);
    resetFilter(): void;
    get filterInput(): cdktf.IResolvable | SecurityMonitoringRuleFilter[] | undefined;
    private _options;
    get options(): SecurityMonitoringRuleOptionsOutputReference;
    putOptions(value: SecurityMonitoringRuleOptions): void;
    resetOptions(): void;
    get optionsInput(): SecurityMonitoringRuleOptions | undefined;
    private _query?;
    get query(): SecurityMonitoringRuleQuery[] | cdktf.IResolvable;
    set query(value: SecurityMonitoringRuleQuery[] | cdktf.IResolvable);
    get queryInput(): cdktf.IResolvable | SecurityMonitoringRuleQuery[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
